@@ -29,8 +29,8 @@ import sys
 import pyfiglet
 
 
-from .scripts import *
-from .scripts.functions import *
+from scripts import *
+from scripts.functions import *
 
 
 def main(args):
